@@ -555,7 +555,7 @@ class MyDebug(object):
                 recv_address = recv_struct.Command_int_A
                 return recv_address
             else:
-                return False
+                return 0
         except Exception:
             return False
         return False
@@ -572,7 +572,7 @@ class MyDebug(object):
                 recv_address = recv_struct.Command_int_A
                 return recv_address
             else:
-                return False
+                return 0
         except Exception:
             return False
         return False
@@ -589,7 +589,7 @@ class MyDebug(object):
                 recv_address = recv_struct.Command_int_A
                 return recv_address
             else:
-                return False
+                return 0
         except Exception:
             return False
         return False
@@ -606,7 +606,7 @@ class MyDebug(object):
                 recv_address = recv_struct.Command_int_A
                 return recv_address
             else:
-                return False
+                return 0
         except Exception:
             return False
         return False
@@ -2141,4 +2141,22 @@ class MyDebug(object):
                 return False
         except Exception:
             return False
-        return False
\ No newline at end of file
+        return False
+
+    # 搜索任意位置处特征码
+    def scan_memory_any(self, address=0, size=0, pattern=""):
+        try:
+            ptr = MyStruct()
+            ptr.Command_String_A = "ScanMemoryAny".encode("utf8")
+            ptr.Command_int_A = address
+            ptr.Command_int_B = size
+            ptr.Command_String_B = pattern.encode("utf-8")
+
+            recv_struct = self.send_recv_struct(ptr)
+            if recv_struct.Flag == 1:
+                return recv_struct.Command_int_C
+            else:
+                return False
+        except Exception:
+            return False
+        return False
